# NSHM: Alaska

National Seismic Hazard Model (NSHM) for the State of Alaska. This model is intended for use with
U.S. Geological Survey (USGS) hazard software [*nshmp-haz*][1] version 2+.

For details on the format of this model, see the *nshmp-haz*
[user guide and implementation reference][2].

## Model Editions

* For prior model editions, see the [USGS Seismic Hazard Maps][3] web page.
* Current edition: development

## Model Notes

Conversion from XML to JSON format: 'characteristic' ruptures on the interface are marked as
`floats="true"` in the MFD, but in the *nshmp-haz* v2+ codes, a `SINGLE` MFD rupture will not
float. We therefore revert to single magnitude GR MFD similar to legacy fortran code to force
floating of 'characteristic' ruptures. See XML for original SINGLE MFDs for Kodiak (fault),
Narrow Cape, Eastern Aleutians, Kodiak (interface) and Transition Zone. For example:

```json
  "aleutians-east": [
    { "id": "floating-single", "weight": 1.0, "value":
      { "type": "GR", "a": 6.3871, "b": 1.0, "mMin": 9.15, "mMax": 9.25, "Δm": 0.1 }
    }
  ]
```

... is equivalent to:

```json
  "aleutians-east": [
    { "id": "full-rupture", "weight": 1.0, "value":
      { "type": "SINGLE", "rate": 0.00153851, "m": 9.2 }
    }
  ]
```

### Source and Logic Tree IDs

TODO update ID table wrt to 2023 model

ID ranges for current and future models:

| Sources                       | ID Range    |
|:------------------------------|:-----------:|
| Crustal Faults                | 4000 - 4499 |
| Crustal Fault Systems         | 4500 - 4599 |
| Crustal Fault Zone Sources    | 4600 - 4649 |
| Crustal Gridded Seismicity    | 4650 - 4699 |
| Intraslab Gridded Seismicity  | 4700 - 4749 |
| Interface Gridded Seismicity  | 4750 - 4799 |
| Interface Sections            | 4800 - 4899 |

## Site Files

The `map.geojson` file defines the latitude-longitude range over which the USGS computes
maps of seismic hazard from this model. The `sites.geojson` and `sites.csv` files
contain the test sites at which the USGS performs more detailed comparisons between model editions.
See the *nshmp-haz* user guide [site specification section][4] for more details on these files.

## References

**Model documentation:** TBD.

**Suggested citation:**  TBD.

### 2007 Implementation Details (from xml repo v2.1.2; TODO clean)

Notable implementation details (in fortran source and inputs) that set Alaska 2007 apart from
later COUS models and this updated nshmp-haz implementation of the Alaska model:

* Grid and slab optimization tables use discretization of 2km out to 200km.
  * nshmp-haz: __discretization = 1km__
* Grid and slab sources use the Wells & Coppersmith (1994) magnitude-length scaling relation.
  * nshmp-haz: __slab sources use Youngs et al. (1997)__ (aka 'geomatrix'; consistent with 2014
    COUS NSHM)
* Grid and slab sources randomize strike at M≥6.
  * nshmp-haz: __uses point-source distance corrections for M≥6__ (in relations above; consistent
    with 2014 COUS NSHM)
* Ground motion models do not impose one-sided 3σ upper truncation on exceedances.
  * nshmp-haz: __no change__
* Other details:
  * nshmp-haz: __grid source maxDepth = 15 km__
* Focal mechansim variations are encoded into coefficients supplied with each input file; flavors
  for strike-slip and mixed strike-slip/reverse were ported from the 2002 COUS model.
  * nshmp-haz: __point sources generate focal mechanism specific ruptures with appropriate rake
    that are processed independently, consistent with 2014 COUS NSHM__
* Aleatory uncertainty was added in the 2002 COUS model and was carried over here as a
  moment-balanced Gaussian distribution on mMax of M±0.15 discretized over 5 values with σ=0.12.
  The 2008 COUS model increased the width of the distribution to M±2σ and increased the
  discretization to 11 values. Both implementations require custom code; the more recent approach
  is more straightforward with the distribution a function of σ.
  * nshmp-haz: __uses more recent (11-point; ±2σ) aleatory uncertainty model__
* Hazard curves are not truncated at 3σ.
  * nshmp-haz: __no change__

### 2007 Other Notes (from xml repo v2.1.2; TODO clean)

* Consistent with 2008 and 2014 COUS models, slab and grid Gutenberg-Richter MFD magnitudes bins are centered on 0.05; interface MFD bins are centered on 0.1.


[1]: https://code.usgs.gov/ghsc/nshmp/nshmp-haz
[2]: https://code.usgs.gov/ghsc/nshmp/nshmp-haz/-/blob/main/docs/README.md
[3]: https://www.usgs.gov/programs/earthquake-hazards/seismic-hazard-maps-and-site-specific-data
[4]: https://code.usgs.gov/ghsc/nshmp/nshmp-haz/-/blob/main/docs/pages/Site-Specification.md
